@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
@@ -60,13 +59,13 @@ typedef struct {
 } PngNeedsMergeData;
 
 typedef struct {
-	gchar *author, *creator, *description, *comment, *copyright, 
-	      *creation_time, *title, *disclaimer;
+	gchar *author, *creator, *description, *comment, *copyright,
+		*creation_time, *title, *disclaimer;
 } PngData;
 
-static gchar *rfc1123_to_iso8601_date (gchar	   *rfc_date);
-static void   extract_png	      (const gchar *filename,
-				       TrackerSparqlBuilder   *metadata);
+static gchar *rfc1123_to_iso8601_date (gchar       *rfc_date);
+static void   extract_png             (const gchar *filename,
+                                       TrackerSparqlBuilder   *metadata);
 
 static TrackerExtractData data[] = {
 	{ "image/png", extract_png },
@@ -93,7 +92,7 @@ insert_keywords (TrackerSparqlBuilder *metadata, const gchar *uri, gchar *keywor
 	keywords = strchr (keywords, '"');
 	if (keywords)
 		keywords++;
-	else 
+	else
 		keywords = keyw;
 
 	len = strlen (keywords);
@@ -118,7 +117,7 @@ insert_keywords (TrackerSparqlBuilder *metadata, const gchar *uri, gchar *keywor
 static void
 read_metadata (png_structp png_ptr, png_infop info_ptr, const gchar *uri, TrackerSparqlBuilder *metadata)
 {
-	gint	     num_text;
+	gint         num_text;
 	png_textp    text_ptr;
 	PngNeedsMergeData merge_data = { 0 };
 	PngData png_data = { 0 };
@@ -137,14 +136,14 @@ read_metadata (png_structp png_ptr, png_infop info_ptr, const gchar *uri, Tracke
 
 			if (g_strcmp0 ("XML:com.adobe.xmp", text_ptr[i].key) == 0) {
 
-				/* ATM tracker_read_xmp supports setting xmp_data 
+				/* ATM tracker_read_xmp supports setting xmp_data
 				 * multiple times, keep it that way as here it's
 				 * theoretically possible that the function gets
 				 * called multiple times */
 
 				tracker_read_xmp (text_ptr[i].text,
-						  text_ptr[i].itxt_length,
-						  uri, &xmp_data);
+				                  text_ptr[i].itxt_length,
+				                  uri, &xmp_data);
 
 				continue;
 			}
@@ -195,20 +194,22 @@ read_metadata (png_structp png_ptr, png_infop info_ptr, const gchar *uri, Tracke
 		                                       png_data.author,
 		                                       xmp_data.creator);
 
-		merge_data.title = tracker_coalesce (2, png_data.title,
-		                                     xmp_data.title);
+		merge_data.title = tracker_coalesce (4, png_data.title,
+		                                     xmp_data.title, 
+		                                     xmp_data.Title,
+		                                     xmp_data.PDFtitle);
 
 		merge_data.copyright = tracker_coalesce (2, png_data.copyright,
 		                                         xmp_data.rights);
 
 		merge_data.license = tracker_coalesce (2, png_data.disclaimer,
-		                                         xmp_data.license);
+		                                       xmp_data.license);
 
 		merge_data.description = tracker_coalesce (2, png_data.description,
 		                                           xmp_data.description);
 
 		merge_data.date = tracker_coalesce (3, png_data.creation_time,
-		                                    xmp_data.date, 
+		                                    xmp_data.date,
 		                                    xmp_data.DateTimeOriginal);
 
 
@@ -267,6 +268,11 @@ read_metadata (png_structp png_ptr, png_infop info_ptr, const gchar *uri, Tracke
 			g_free (xmp_data.keywords);
 		}
 
+		if (xmp_data.PDFkeywords) {
+			insert_keywords (metadata, uri, xmp_data.PDFkeywords);
+			g_free (xmp_data.PDFkeywords);
+		}
+
 		if (xmp_data.subject) {
 			insert_keywords (metadata, uri, xmp_data.subject);
 			g_free (xmp_data.subject);
@@ -397,23 +403,57 @@ read_metadata (png_structp png_ptr, png_infop info_ptr, const gchar *uri, Tracke
 			tracker_sparql_builder_object_unvalidated (metadata, xmp_data.MeteringMode);
 			g_free (xmp_data.MeteringMode);
 		}
+	
+		if (xmp_data.Address || xmp_data.Country || xmp_data.City) {
+			tracker_sparql_builder_predicate (metadata, "mlo:location");
+	
+			tracker_sparql_builder_object_blank_open (metadata);
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
+	
+			if (xmp_data.Address) {
+				tracker_sparql_builder_predicate (metadata, "mlo:address");
+				tracker_sparql_builder_object_unvalidated (metadata, xmp_data.Address);
+				g_free (xmp_data.Address);
+			}
+	
+			if (xmp_data.State) {
+				tracker_sparql_builder_predicate (metadata, "mlo:state");
+				tracker_sparql_builder_object_unvalidated (metadata, xmp_data.State);
+				g_free (xmp_data.State);
+			}
+	
+			if (xmp_data.City) {
+				tracker_sparql_builder_predicate (metadata, "mlo:city");
+				tracker_sparql_builder_object_unvalidated (metadata, xmp_data.City);
+				g_free (xmp_data.City);
+			}
+	
+			if (xmp_data.Country) {
+				tracker_sparql_builder_predicate (metadata, "mlo:country");
+				tracker_sparql_builder_object_unvalidated (metadata, xmp_data.Country);
+				g_free (xmp_data.Country);
+			}
+		
+			tracker_sparql_builder_object_blank_close (metadata);
+		}
 	}
 }
 
 static void
 extract_png (const gchar *uri,
-	     TrackerSparqlBuilder   *metadata)
+             TrackerSparqlBuilder   *metadata)
 {
 	goffset      size;
-	FILE	    *f;
+	FILE        *f;
 	png_structp  png_ptr;
 	png_infop    info_ptr;
 	png_infop    end_ptr;
 	png_bytepp   row_pointers;
 	guint        row;
 	png_uint_32  width, height;
-	gint	     bit_depth, color_type;
-	gint	     interlace_type, compression_type, filter_type;
+	gint         bit_depth, color_type;
+	gint         interlace_type, compression_type, filter_type;
 	gchar       *filename = g_filename_from_uri (uri, NULL, NULL);
 
 	size = tracker_file_get_size (filename);
@@ -422,13 +462,13 @@ extract_png (const gchar *uri,
 		return;
 	}
 
-	f = tracker_file_open (filename, "r", FALSE); 
+	f = tracker_file_open (filename, "r", FALSE);
 
 	if (f) {
 		png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING,
-						  NULL,
-						  NULL,
-						  NULL);
+		                                  NULL,
+		                                  NULL,
+		                                  NULL);
 		if (!png_ptr) {
 			tracker_file_close (f, FALSE);
 			g_free (filename);
@@ -461,20 +501,20 @@ extract_png (const gchar *uri,
 		png_read_info (png_ptr, info_ptr);
 
 		if (!png_get_IHDR (png_ptr,
-				   info_ptr,
-				   &width,
-				   &height,
-				   &bit_depth,
-				   &color_type,
-				   &interlace_type,
-				   &compression_type,
-				   &filter_type)) {
+		                   info_ptr,
+		                   &width,
+		                   &height,
+		                   &bit_depth,
+		                   &color_type,
+		                   &interlace_type,
+		                   &compression_type,
+		                   &filter_type)) {
 			png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 			tracker_file_close (f, FALSE);
 			g_free (filename);
 			return;
 		}
-		
+
 		/* Read the image. FIXME We should be able to skip this step and
 		 * just get the info from the end. This causes some errors atm.
 		 */
@@ -482,7 +522,7 @@ extract_png (const gchar *uri,
 
 		for (row = 0; row < height; row++) {
 			row_pointers[row] = png_malloc (png_ptr,
-							png_get_rowbytes (png_ptr,info_ptr));
+			                                png_get_rowbytes (png_ptr,info_ptr));
 		}
 
 		png_read_image (png_ptr, row_pointers);
