@@ -25,10 +25,12 @@
 #include <glib.h>
 
 typedef struct {
-	gchar *keywords, *date_created, *byline, *credit, *copyright_notice, 
-	      *image_orientation;
+	gchar *keywords, *date_created, *byline, *credit, *copyright_notice,
+		*image_orientation, *bylinetitle, *city, *state, *sublocation,
+		*countryname, *contact;
 } TrackerIptcData;
 
+
 void tracker_read_iptc (const unsigned char *buffer,
                         size_t               len,
                         const gchar         *uri,
