@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008-2009, Nokia
@@ -32,15 +31,15 @@
 #include <libtracker-client/tracker.h>
 #include <libtracker-common/tracker-common.h>
 
-#define ABOUT                                                             \
-        "Tracker " PACKAGE_VERSION "\n"
+#define ABOUT	  \
+	"Tracker " PACKAGE_VERSION "\n"
 
-#define LICENSE                                                           \
-        "This program is free software and comes without any warranty.\n" \
-        "It is licensed under version 2 or later of the General Public "  \
-        "License which can be viewed at:\n"                               \
-        "\n"                                                              \
-        "  http://www.gnu.org/licenses/gpl.txt\n"
+#define LICENSE	  \
+	"This program is free software and comes without any warranty.\n" \
+	"It is licensed under version 2 or later of the General Public " \
+	"License which can be viewed at:\n" \
+	"\n" \
+	"  http://www.gnu.org/licenses/gpl.txt\n"
 
 static gchar        **filenames = NULL;
 static gboolean       print_version;
@@ -87,8 +86,8 @@ has_valid_uri_scheme (const gchar *uri)
 int
 main (int argc, char **argv)
 {
-	TrackerClient	*client;
-	GOptionContext	*context;
+	TrackerClient   *client;
+	GOptionContext  *context;
 	gchar          **p;
 
 	setlocale (LC_ALL, "");
@@ -97,17 +96,17 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/* Translators: this messagge will apper immediately after the	*/
-	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>	*/
+	/* Translators: this messagge will apper immediately after the  */
+	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>     */
 	context = g_option_context_new (_("- Get all information about one or more files"));
 
 	/* Translators: this message will appear after the usage string */
-	/* and before the list of options.				*/
+	/* and before the list of options.                              */
 	g_option_context_add_main_entries (context, entries, NULL);
 	g_option_context_parse (context, &argc, &argv, NULL);
 
-     	if (print_version) {
-                g_print ("\n" ABOUT "\n" LICENSE "\n");
+	if (print_version) {
+		g_print ("\n" ABOUT "\n" LICENSE "\n");
 		g_option_context_free (context);
 
 		return EXIT_SUCCESS;
@@ -117,7 +116,7 @@ main (int argc, char **argv)
 		gchar *help;
 
 		g_printerr ("%s\n\n",
-			    _("One or more files have not been specified"));
+		            _("One or more files have not been specified"));
 
 		help = g_option_context_get_help (context, TRUE, NULL);
 		g_option_context_free (context);
@@ -133,62 +132,62 @@ main (int argc, char **argv)
 
 	if (!client) {
 		g_printerr ("%s\n",
-			    _("Could not establish a D-Bus connection to Tracker"));
+		            _("Could not establish a D-Bus connection to Tracker"));
 		return EXIT_FAILURE;
 	}
 
-        for (p = filenames; *p; p++) {
+	for (p = filenames; *p; p++) {
 		GPtrArray *results;
 		GError    *error = NULL;
 		gchar     *uri;
 		gchar     *query;
 
 		g_print ("%s:'%s'\n",
-			 _("Querying information for file"),
-			 *p);
-	
+		         _("Querying information for file"),
+		         *p);
+
 		/* support both, URIs and local file paths */
 		if (has_valid_uri_scheme (*p)) {
 			uri = g_strdup (*p);
 		} else {
 			GFile *file;
-			
+
 			file = g_file_new_for_commandline_arg (*p);
 			uri = g_file_get_uri (file);
 			g_object_unref (file);
 		}
-		
+
 		query = g_strdup_printf ("SELECT ?predicate ?object WHERE { <%s> ?predicate ?object }", uri);
-		
+
 		results = tracker_resources_sparql_query (client, query, &error);
-		
+
 		g_free (uri);
 		g_free (query);
 
 		if (error) {
 			g_printerr ("  %s, %s\n",
-				    _("Unable to retrieve data for URI"),
-				    error->message);
-			
+			            _("Unable to retrieve data for URI"),
+			            error->message);
+
 			g_error_free (error);
 			continue;
 		}
-		
+
 		if (!results) {
 			g_print ("  %s\n",
-				 _("No metadata available for that URI"));
+			         _("No metadata available for that URI"));
 		} else {
 			gint length;
-			
+
 			length = results->len;
-			
-			g_print (tracker_dngettext (NULL,
-						    "Result: %d", 
-						    "Results: %d",
-						    length),
-				 length);
+
+			g_print (g_dngettext (NULL,
+			                      "Result: %d",
+			                      "Results: %d",
+			                      length),
+			         length);
 			g_print ("\n");
-			
+
 			g_ptr_array_foreach (results, (GFunc) print_property_value, NULL);
 			g_ptr_array_foreach (results, (GFunc) g_strfreev, NULL);
 			g_ptr_array_free (results, TRUE);
